import {useEffect, useMemo, useState} from "react";
import dayjs from "dayjs";
import {DATE_TIME_FORMAT} from "../utils/timeFormatUtil";
import {getTaskByPid} from "../utils";
import {Cascader} from "antd-mobile";

export function useChildList() {
    const [task, setTask] = useState({
        name: "想做的事情",
        description: "想做的事情描述",
        expectedStartTime: dayjs().format(DATE_TIME_FORMAT),
        expectedEndTime: "",
        state: "",
        priority: "",
    });
    // Map key为pid和他的子项
    const [childList, setChildList] = useState({});
    const [searchValue, setSearchValue] = useState("");
    // 当前选中的值，使用值过滤其子孙。
    const [selectValue, setSelectValue] = useState([]);
    const [currentLab, setCurrentLab] = useState(0);
    const [initPidArray, setInitPidArray] = useState([]);

    function changeInitPidArray(){
        setInitPidArray([...initPidArray]);
    }

    useEffect(() => {
        fetchOptionsForValue('0', 0)
        initPidArray.forEach(id => {
            fetchOptionsForValue(id,0)
        })
    }, [initPidArray])

    // list嵌套选中项的list
    const options = useMemo(() => {
        function generate(v) {
            const options = childList[v]
            if (options === null) {
                return undefined
            }
            if (options === undefined) {
                return Cascader.optionSkeleton
            }
            // 如果有搜索有值，需要过滤，
            // 根据currentLab查看需要过滤第几层，当前层可能没有值就会停留在上一层
            if (searchValue && searchValue.length > 0) {
                if (selectValue.length <= currentLab + 1) {
                    // 可能展示最新的，或没有停留在当前页面，正常是没有选择的时候搜索
                    console.log({searchValue}, {currentLab}, {selectValue})
                    if (currentLab === 0 && v === '0') {
                        return options.filter(option => option.label.includes(searchValue)).map(option => ({
                            ...option,
                            children: generate(option.value),
                        }))
                    } else if (v === selectValue[currentLab - 1]) {
                        return options.filter(option => option.label.includes(searchValue)).map(option => ({
                            ...option,
                            children: generate(option.value),
                        }))
                    }
                } else {
                    // 用户切换回之前的标签，暂不处理
                }
            }
            return options.map(option => ({
                ...option,
                children: generate(option.value),
            }))
        }

        return generate('0') ?? []
    }, [childList,searchValue])

    async function fetchOptionsForValue(v, level) {
        if (v in childList) return
        const data = await getTaskByPid(v)
        const options =
            data.content.length === 0
                ? null
                : data.content.map(task => ({
                    value: task.id,
                    label: task.name,
                    ...task,
                }))

        setChildList(prev => ({
            ...prev,
            [v]: options,
        }))

    }

    function changeSearchValue(value) {
        setSearchValue(value)
    }

    function changeCurrentLab(value) {
        setCurrentLab(value)
    }

    function changeSelectValue(value){
        setSelectValue(value)
    }

    function changeTaskId(taskId) {
        if (!(taskId && taskId.length > 0)) {
            return;
        }
        let currentTaskId = taskId[taskId.length - 1];
        fetchOptionsForValue(currentTaskId);
        if (taskId.length > 1) {
            setTask(childList[taskId[taskId.length - 2]].find(task => task.id === currentTaskId))
        } else {
            setTask(childList['0'].find(task => task.id === currentTaskId))
        }
    }

    function removeTaskId(taskId) {
        childList.delete(taskId);
        setChildList(...childList)
    }

    return {
        changeTaskId,
        removeTaskId,
        changeInitPidArray,
        changeCurrentLab,
        changeSearchValue,
        changeSelectValue,
        options,
        task
    };
}